==> jc-1.4.0.tar.gz: javax/accessibility/AccessibleBundle.h <==
// public abstract class javax.accessibility.AccessibleBundle

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 31af68d307de0dce javax_accessibility_AccessibleBundle

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_accessibility_AccessibleBundle_H_
#define _JC_javax_accessibility_AccessibleBundle_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Locale$object;

// Typedefs
typedef struct _jc_javax_accessibility_AccessibleBundle$sub_refs	_jc_javax_accessibility_AccessibleBundle$sub_refs;
typedef struct _jc_javax_accessibility_AccessibleBundle$sub_nonrefs	_jc_javax_accessibility_AccessibleBundle$sub_nonrefs;
typedef struct _jc_javax_accessibility_AccessibleBundle$refs	_jc_javax_accessibility_AccessibleBundle$refs;
typedef struct _jc_javax_accessibility_AccessibleBundle$nonrefs	_jc_javax_accessibility_AccessibleBundle$nonrefs;
typedef struct _jc_javax_accessibility_AccessibleBundle$object	_jc_javax_accessibility_AccessibleBundle$object;

typedef const struct _jc_javax_accessibility_AccessibleBundle$vmethods	_jc_javax_accessibility_AccessibleBundle$vmethods;
typedef const struct _jc_javax_accessibility_AccessibleBundle$vtable	_jc_javax_accessibility_AccessibleBundle$vtable;
typedef const struct _jc_javax_accessibility_AccessibleBundle$vtype	_jc_javax_accessibility_AccessibleBundle$vtype;

// Constructors
extern void _jc_javax_accessibility_AccessibleBundle$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_accessibility_AccessibleBundle$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_accessibility_AccessibleBundle$method$toDisplayString$b4f31620c59918c2(_jc_env *, struct _jc_javax_accessibility_AccessibleBundle$object *);
extern struct _jc_java_lang_String$object *_jc_javax_accessibility_AccessibleBundle$method$toDisplayString$3c924db121cdc1b6(_jc_env *, struct _jc_javax_accessibility_AccessibleBundle$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Locale$object *);
extern struct _jc_java_lang_String$object *_jc_javax_accessibility_AccessibleBundle$method$toDisplayString$6d25eed44001aa94(_jc_env *, struct _jc_javax_accessibility_AccessibleBundle$object *, struct _jc_java_util_Locale$object *);
extern struct _jc_java_lang_String$object *_jc_javax_accessibility_AccessibleBundle$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_accessibility_AccessibleBundle$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_accessibility_AccessibleBundle$method_info$toDisplayString$b4f31620c59918c2;
extern _jc_method _jc_javax_accessibility_AccessibleBundle$method_info$toDisplayString$3c924db121cdc1b6;
extern _jc_method _jc_javax_accessibility_AccessibleBundle$method_info$toDisplayString$6d25eed44001aa94;
extern _jc_method _jc_javax_accessibility_AccessibleBundle$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_accessibility_AccessibleBundle$vmethods {
	struct _jc_java_lang_String$object	*(*toDisplayString$b4f31620c59918c2)(_jc_env *, struct _jc_javax_accessibility_AccessibleBundle$object *);
	struct _jc_java_lang_String$object	*(*toDisplayString$3c924db121cdc1b6)(_jc_env *, struct _jc_javax_accessibility_AccessibleBundle$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Locale$object *);
	struct _jc_java_lang_String$object	*(*toDisplayString$6d25eed44001aa94)(_jc_env *, struct _jc_javax_accessibility_AccessibleBundle$object *, struct _jc_java_util_Locale$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_accessibility_AccessibleBundle$object *);
};

// Vtable
struct _jc_javax_accessibility_AccessibleBundle$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleBundle$vmethods	javax_accessibility_AccessibleBundle;
};

// Vtype
struct _jc_javax_accessibility_AccessibleBundle$vtype {
	_jc_type			type;
	_jc_javax_accessibility_AccessibleBundle$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_accessibility_AccessibleBundle$sub_refs {
	struct _jc_java_lang_String$object	*key;
};

// Reference instance fields (object)
struct _jc_javax_accessibility_AccessibleBundle$refs {
    _jc_javax_accessibility_AccessibleBundle$sub_refs	javax_accessibility_AccessibleBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_accessibility_AccessibleBundle$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_accessibility_AccessibleBundle$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleBundle$sub_nonrefs	javax_accessibility_AccessibleBundle;
};

// Object instance structure
struct _jc_javax_accessibility_AccessibleBundle$object {
	_jc_javax_accessibility_AccessibleBundle$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_accessibility_AccessibleBundle$vtype	*vtype;
	_jc_javax_accessibility_AccessibleBundle$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_accessibility_AccessibleBundle$vtype _jc_javax_accessibility_AccessibleBundle$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_accessibility_AccessibleBundle, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_accessibility_AccessibleBundle$class_object;

#endif	/* _JC_javax_accessibility_AccessibleBundle_H_ */

==> jc-1.4.6.tar.gz: javax/accessibility/AccessibleBundle.h <==
// public abstract class javax.accessibility.AccessibleBundle

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 31af68d307de0dce javax_accessibility_AccessibleBundle

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_accessibility_AccessibleBundle_H_
#define _JC_javax_accessibility_AccessibleBundle_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Locale$object;

// Typedefs
typedef struct _jc_javax_accessibility_AccessibleBundle$sub_refs	_jc_javax_accessibility_AccessibleBundle$sub_refs;
typedef struct _jc_javax_accessibility_AccessibleBundle$sub_nonrefs	_jc_javax_accessibility_AccessibleBundle$sub_nonrefs;
typedef struct _jc_javax_accessibility_AccessibleBundle$refs	_jc_javax_accessibility_AccessibleBundle$refs;
typedef struct _jc_javax_accessibility_AccessibleBundle$nonrefs	_jc_javax_accessibility_AccessibleBundle$nonrefs;
typedef struct _jc_javax_accessibility_AccessibleBundle$object	_jc_javax_accessibility_AccessibleBundle$object;

typedef const struct _jc_javax_accessibility_AccessibleBundle$vmethods	_jc_javax_accessibility_AccessibleBundle$vmethods;
typedef const struct _jc_javax_accessibility_AccessibleBundle$vtable	_jc_javax_accessibility_AccessibleBundle$vtable;
typedef const struct _jc_javax_accessibility_AccessibleBundle$vtype	_jc_javax_accessibility_AccessibleBundle$vtype;

// Constructors
extern void _jc_javax_accessibility_AccessibleBundle$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_accessibility_AccessibleBundle$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_accessibility_AccessibleBundle$method$toDisplayString$b4f31620c59918c2(_jc_env *, struct _jc_javax_accessibility_AccessibleBundle$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_accessibility_AccessibleBundle$method$toDisplayString$3c924db121cdc1b6(_jc_env *, struct _jc_javax_accessibility_AccessibleBundle$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Locale$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_accessibility_AccessibleBundle$method$toDisplayString$6d25eed44001aa94(_jc_env *, struct _jc_javax_accessibility_AccessibleBundle$object *, struct _jc_java_util_Locale$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_accessibility_AccessibleBundle$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_accessibility_AccessibleBundle$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_accessibility_AccessibleBundle$method_info$toDisplayString$b4f31620c59918c2;
extern _jc_method _jc_javax_accessibility_AccessibleBundle$method_info$toDisplayString$3c924db121cdc1b6;
extern _jc_method _jc_javax_accessibility_AccessibleBundle$method_info$toDisplayString$6d25eed44001aa94;
extern _jc_method _jc_javax_accessibility_AccessibleBundle$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_accessibility_AccessibleBundle$vmethods {
	struct _jc_java_lang_String$object	*(*toDisplayString$b4f31620c59918c2)(_jc_env *, struct _jc_javax_accessibility_AccessibleBundle$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toDisplayString$3c924db121cdc1b6)(_jc_env *, struct _jc_javax_accessibility_AccessibleBundle$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Locale$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toDisplayString$6d25eed44001aa94)(_jc_env *, struct _jc_javax_accessibility_AccessibleBundle$object *, struct _jc_java_util_Locale$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_accessibility_AccessibleBundle$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_accessibility_AccessibleBundle$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleBundle$vmethods	javax_accessibility_AccessibleBundle;
};

// Vtype
struct _jc_javax_accessibility_AccessibleBundle$vtype {
	_jc_type			type;
	_jc_javax_accessibility_AccessibleBundle$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_accessibility_AccessibleBundle$sub_refs {
	struct _jc_java_lang_String$object	*key;
};

// Reference instance fields (object)
struct _jc_javax_accessibility_AccessibleBundle$refs {
    _jc_javax_accessibility_AccessibleBundle$sub_refs	javax_accessibility_AccessibleBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_accessibility_AccessibleBundle$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_accessibility_AccessibleBundle$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleBundle$sub_nonrefs	javax_accessibility_AccessibleBundle;
};

// Object instance structure
struct _jc_javax_accessibility_AccessibleBundle$object {
	_jc_javax_accessibility_AccessibleBundle$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_accessibility_AccessibleBundle$vtype	*vtype;
	_jc_javax_accessibility_AccessibleBundle$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_accessibility_AccessibleBundle$vtype _jc_javax_accessibility_AccessibleBundle$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_accessibility_AccessibleBundle, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_accessibility_AccessibleBundle$class_object;

#endif	/* _JC_javax_accessibility_AccessibleBundle_H_ */
